package come.stormborntales.notevault

import android.content.Context
import android.net.Uri
import android.os.Bundle
import android.util.Log
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.activity.result.ActivityResultLauncher
import androidx.activity.result.PickVisualMediaRequest
import androidx.activity.result.contract.ActivityResultContracts
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateListOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import come.stormborntales.notevault.ui.screens.MainScreen
import come.stormborntales.notevault.ui.theme.NoteVaultTheme
import java.io.File
import java.io.InputStream

class MainActivity : ComponentActivity() {
    private lateinit var imagePickerLauncher: ActivityResultLauncher<PickVisualMediaRequest>
    // Definiere notes als MutableStateList für die gesamte Aktivität
    private val notes = mutableStateListOf<Uri>()
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        // Launcher für die Bildauswahl einrichten
        imagePickerLauncher = registerForActivityResult(ActivityResultContracts.PickVisualMedia()) { uri ->
            uri?.let {
                // Hier kannst du die Logik zum Speichern und Anzeigen des Bildes hinzufügen
                val context: Context = applicationContext
                val inputStream: InputStream? = contentResolver.openInputStream(uri)
                val outputFile = File(context.filesDir, "note_${System.currentTimeMillis()}.jpg")

                inputStream?.use { input ->
                    outputFile.outputStream().use { output ->
                        input.copyTo(output)
                        addNoteToList(notes, it)
                    }
                }

                Log.d("MainActivity", "Bild gespeichert: ${outputFile.absolutePath}")

            }
        }

        setContent {
            NoteVaultTheme {
                MainScreen(
                    onAddNoteClicked = {
                        // Öffne die Galerie zum Auswählen eines Bildes
                        imagePickerLauncher.launch(PickVisualMediaRequest(ActivityResultContracts.PickVisualMedia.ImageAndVideo))
                    },
                    notes = notes,
                )
            }
        }
    }
}

// Funktion zum Hinzufügen von Noten zur Liste
private fun addNoteToList(notes: MutableList<Uri>, uri: Uri) {
    // Hier wird das Bild zur Liste hinzugefügt
    notes.add(uri)
}